@@ -15,9 +15,4 @@
 
 # You should have received a copy of the GNU General Public License along
 # with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-
-from .Seals import process
-from .Seals import Insert
-from .Seals import scan
-from .Seals import write
\ No newline at end of file
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
\ No newline at end of file
